@@ -10,8 +10,8 @@ testWarnOnEmptyConfig() {
 
 testWithUrlfile(){
     export HOME=$AUTOPKGTEST_TMP
-    echo -e "---\nname: \"tmp listing\"\ncommand: \"ls -al $AUTOPKGTEST_TMP\"" > $AUTOPKGTEST_TMP/urls.json
-    urlwatch --urls $AUTOPKGTEST_TMP/urls.json
+    echo -e "---\nname: \"tmp listing\"\ncommand: \"ls -al $AUTOPKGTEST_TMP\"" > "$AUTOPKGTEST_TMP/urls.json"
+    urlwatch --urls "$AUTOPKGTEST_TMP/urls.json"
     result=$?
     assertEquals "Urlwatch should return an exit code 0" 0 $result
 }
